@@ -8,6 +8,6 @@ from python_testing_advanced import python_testing_advanced
 
 
 def test_help():
-    """python_testing_advanced :: Unit :: python_testing_advanced :: help"""
+    """Unit :: python_testing_advanced :: help"""
     assert python_testing_advanced.help() == \
         'Python Testing Advanced Tutorial Module'
